@@ -15,7 +15,7 @@
 /*! 
  * \file libircclient.h
  * \author George Yunaev
- * \version 1.5
+ * \version 1.9
  * \date 01.2012
  * \brief This file defines all prototypes and functions to use libircclient.
  *
@@ -44,7 +44,9 @@
 #ifndef INCLUDE_LIBIRC_H
 #define INCLUDE_LIBIRC_H
 
-#if !defined (WIN32)
+#include <stdlib.h>
+
+#if !defined (_WIN32)
 	#include <sys/select.h>	/* fd_set */
 #else
 	#include <winsock2.h>
@@ -1050,7 +1052,7 @@ int irc_cmd_ctcp_reply (irc_session_t * session, const char * nick, const char *
  * \fn void irc_target_get_nick (const char * target, char *nick, size_t size)
  * \brief Gets the nick part from the target
  *
- * \param target  A nick in common IRC server form like tim!root\@mycomain.com
+ * \param target  A nick in common IRC server form like tim!root\@mycomain.com; cannot be NULL
  * \param nick    A buffer to hold the nickname.
  * \param size    A buffer size. If nick is longer than buffer size, it will 
  *                be truncated.
@@ -1305,6 +1307,20 @@ void irc_get_version (unsigned int * high, unsigned int * low);
  */
 void irc_set_ctx (irc_session_t * session, void * ctx);
 
+/*!
+ * \fn void irc_set_ctcp_version (irc_session_t * session, const char *version)
+ * \brief Sets the internal CTCP VERSION
+ *
+ * \param session an Initiated session.
+ * \param version the version to reply
+ *
+ * This function sets an internal user-defined version to reply on CTCP
+ * VERSION request. If none is given, a default one is provided. The parameter
+ * version is copied and can be freed by the user.
+ *
+ * \ingroup contexts
+ */
+void irc_set_ctcp_version(irc_session_t * session, const char * version);
 
 /*!
  * \fn void * irc_get_ctx (irc_session_t * session)
